package com.yvr.testtobsetting;

import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.WindowManager;
import android.view.inputmethod.InputMethodManager;

import androidx.appcompat.app.ActionBar;
import androidx.appcompat.widget.SearchView;
import androidx.fragment.app.FragmentManager;
import androidx.fragment.app.FragmentTransaction;

import com.yvr.testtobsetting.base.BaseActivity;
import com.yvr.testtobsetting.test.MainFragment;
import com.yvr.testtobsetting.base.BaseFragment;
import com.yvr.testtobsetting.base.FragmentUtil;
import com.yvr.tobsettings.ToBServiceHelper;

import java.util.List;

public class MainActivity extends BaseActivity {
    private static final String TAG = "MainActivity";
    private boolean mServiceConnected;
    private FragmentManager mFragmentManager;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.layout_main);

        //初始化SDK
        //ToBServiceHelper.init(this);


        getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);
        ActionBar actionBar = getSupportActionBar();
        if (actionBar != null) {
            actionBar.setDisplayHomeAsUpEnabled(true);
        }
        mResultView = findViewById(R.id.result);
        mEditText = findViewById(R.id.edit_text);

        serviceCallback();

        MainFragment mainFragment = new MainFragment();
        mainFragment.setServiceConnect(mServiceConnected);

        mFragmentManager = getSupportFragmentManager();
        FragmentTransaction ft = mFragmentManager.beginTransaction();
        ft.add(R.id.main_container, mainFragment);
        ft.commit();

        /*new Thread(() -> {
            int count = 0;
            while (true) {
                Log.d(TAG, "screen off - " + count);
                count++;
                try {
                    Thread.sleep(1000);
                } catch (InterruptedException e) {
                    throw new RuntimeException(e);
                }
            }
        }).start();*/
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case android.R.id.home:
                onBackPressed();
                break;
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.search, menu);
        MenuItem searchItem = menu.findItem(R.id.search);
        SearchView searchView = (SearchView) searchItem.getActionView();
        searchView.setOnQueryTextListener(new SearchView.OnQueryTextListener() {

            @Override
            public boolean onQueryTextSubmit(String query) {
                InputMethodManager imm = (InputMethodManager) getSystemService(
                        Context.INPUT_METHOD_SERVICE);
                if (imm != null) {
                    imm.hideSoftInputFromWindow(searchView.getWindowToken(), 0);
                }
                searchView.clearFocus();
                BaseFragment currentFragment = (BaseFragment) mFragmentManager
                        .findFragmentById(R.id.main_container);
                if (currentFragment != null && currentFragment.isVisible()) {
                    currentFragment.doCommandQuery(query);
                }
                return true;
            }

            @Override
            public boolean onQueryTextChange(String newText) {
                return false;
            }
        });
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        ToBServiceHelper.getInstance().removeTrackingKeyEventCallback();
    }

    private void serviceCallback() {
        ToBServiceHelper.setServiceStateCallback( state -> {
            mServiceConnected = state;
            List<BaseFragment> fragments = FragmentUtil.getInstance().getFragments();
            for (BaseFragment fragment : fragments) {
                Log.d(TAG, "fragment:" + fragment);
                fragment.setServiceConnect(mServiceConnected);
            }
        });
    }
}