package com.yvr.testtobsetting.base;

import android.content.Context;
import android.os.Bundle;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentTransaction;

import com.yvr.testtobsetting.R;

public abstract class BaseFragment extends Fragment {

    private static final String TAG = "BaseFragment";
    public boolean mServiceConnected;
    public OnViewItemClick mViewItemClick;

    public void setServiceConnect(boolean connect) {
        mServiceConnected = connect;
    }

    public boolean doItemClick(BaseItem item) {
        return false;
    }

    //Fragment receive the click action
    public boolean doClickListener() {
        return false;
    }

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if (doClickListener()) {
            mViewItemClick = item -> {
                if (!doItemClick(item)) {
                    //Default is switch fragment
                    BaseFragment fragment = item.getFragment();
                    Log.d(TAG, "fragment:" + fragment);
                    if (fragment != null) {
                        switchFragment(fragment);
                    }
                }
            };
        }
    }

    public void switchFragment(BaseFragment fragment) {
        if (fragment != null) {
            fragment.setServiceConnect(mServiceConnected);
            FragmentTransaction ft = getFragmentManager().beginTransaction();
            ft.replace(R.id.main_container, fragment);
            ft.addToBackStack(null).commit();
        }
    }

    @Override
    public void onAttach(@NonNull Context context) {
        super.onAttach(context);
        FragmentUtil.getInstance().addFragment(this);
    }

    @Override
    public void onDetach() {
        super.onDetach();
        FragmentUtil.getInstance().removeFragment(this);
    }

    public abstract void doCommandQuery(String query);
}
