package com.yvr.testtobsetting.base;

import android.content.Context;
import android.widget.Toast;

import com.yvr.testtobsetting.R;

public abstract class BaseItem {
    public String TAG = "BaseItem_";
    protected Context mContext;
    public boolean mServiceConnected = false;
    private boolean redColor = false;
    private BaseFragment mFragment = null;
    private OnViewItemClick mClick;

    public BaseItem(Context context) {
        mContext = context;
    }

    public boolean isRedColor() {
        return redColor;
    }

    public void setRedColor() {
        redColor = true;
    }

    public void setFragment(BaseFragment fragment, OnViewItemClick click) {
        mFragment = fragment;
        mClick = click;
    }

    public void setClickListener(OnViewItemClick click) {
        mClick = click;
    }

    public BaseFragment getFragment() {
        return mFragment;
    }

    public void setServiceConnect(boolean connected) {
        mServiceConnected = connected;
    }

    public String onItemClick() {
        if (!mServiceConnected) {
            return mContext.getString(R.string.service_null);
        } else {
            if (mClick != null) {
                mClick.onItemClick(this);
                return "";
            }
            return itemClickResult();
        }
    }

    public String showResult(int resId, String value) {
        return mContext.getString(resId) + " : " + value;
    }

    public String showResult(int resId, boolean value) {
        return mContext.getString(resId) + " : " +
                (value ? mContext.getString(R.string.result_success)
                        : mContext.getString(R.string.result_fail));
    }

    public void showResultToast(int resId, String value) {
        String result = mContext.getString(resId) + " : " + value;
        Toast.makeText(mContext, result, Toast.LENGTH_SHORT).show();
    }

    public String showOpenCloseResult(int resId, boolean value) {
        return mContext.getString(resId)  + " : " +
                (value ? mContext.getString(R.string.result_open)
                        : mContext.getString(R.string.result_close));
    }

    public String showYesNoResult(int resId, boolean value) {
        return mContext.getString(resId) + " : " +
                (value ? mContext.getString(R.string.result_yes)
                        : mContext.getString(R.string.result_no));
    }

    //测试项的名称
    public abstract String getName();
    //测试项的执行操作
    protected abstract String itemClickResult();
}
