package com.yvr.testtobsetting.base;

import android.content.Context;
import android.graphics.Color;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.yvr.testtobsetting.R;

import java.util.List;

public class RecyclerAdapter extends RecyclerView.Adapter<RecyclerView.ViewHolder> {

    private final Context mContext;
    private final List<BaseItem> mData;
    private final OnItemClickListener mListener;

    public interface OnItemClickListener {
        void onItemClick(String result);
    }

    public RecyclerAdapter(Context context, List<BaseItem> data, OnItemClickListener listener) {
        mContext = context;
        mData = data;
        mListener = listener;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View itemView = LayoutInflater.from(mContext).inflate(R.layout.item_layout, parent,
                false);
        return new NormalHolder(itemView);
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder holder, int position) {
        NormalHolder normalHolder = (NormalHolder) holder;
        normalHolder.getTextView().setText(mData.get(position).getName());
        if (mData.get(position).isRedColor()) {
            normalHolder.getTextView().setTextColor(Color.RED);
        } else {
            normalHolder.getTextView().setTextColor(Color.GRAY);
        }
        normalHolder.getTextView().setOnClickListener(v -> {
            String result = mData.get(position).onItemClick();
            if (mListener != null) {
                mListener.onItemClick(result);
            }
        });
    }

    @Override
    public int getItemCount() {
        return mData.size();
    }

    public void setServiceConnect(boolean connect) {
        for (BaseItem item : mData) {
            item.setServiceConnect(connect);
        }
    }

    public static class NormalHolder extends RecyclerView.ViewHolder {
        private final TextView mTV;
        public NormalHolder(@NonNull View itemView) {
            super(itemView);
            mTV = itemView.findViewById(R.id.item_tv);
        }

        public TextView getTextView() {
            return mTV;
        }
    }
}
