package com.yvr.testtobsetting.test;

import android.content.Context;
import android.os.Message;

import com.yvr.testtobsetting.R;
import com.yvr.testtobsetting.base.BaseActivity;
import com.yvr.testtobsetting.base.BaseTwoItems;
import com.yvr.tobsettings.IKeyEventCallback;
import com.yvr.tobsettings.KeyConstants;
import com.yvr.tobsettings.ToBServiceHelper;

public class KeyEventObserverTest extends BaseTwoItems {
    BaseActivity baseActivity;

    public KeyEventObserverTest(Context context) {
        super(context);
        if (context instanceof BaseActivity) {
            baseActivity = (BaseActivity) context;
        }
    }

    @Override
    public String getSecondName() {
        return mContext.getString(R.string.remove_keyevent_observer);
    }

    @Override
    public String secondItemClickResult() {
        ToBServiceHelper.getInstance().removeTrackingKeyEventCallback();
        return null;
    }

    @Override
    public String getName() {
        return mContext.getString(R.string.add_keyevent_observer);
    }

    private void printKeyEventInfo(int mask, boolean down) {
        String keyEventMsg = "";
        String suffix = down ? "Down" : "Up";
        switch (mask) {
            case KeyConstants.KEY_A:
                keyEventMsg = "KEY_A:" + suffix;
                break;
            case KeyConstants.KEY_B:
                keyEventMsg = "KEY_B:" + suffix;
                break;
            case KeyConstants.KEY_X:
                keyEventMsg = "KEY_X:" + suffix;
                break;
            case KeyConstants.KEY_Y:
                keyEventMsg = "KEY_Y:" + suffix;
                break;
            case KeyConstants.KEY_MENU:
                keyEventMsg = "KEY_MENU:" + suffix;
                break;
            case KeyConstants.KEY_HOME:
                keyEventMsg = "KEY_HOME:" + suffix;
                break;
            case KeyConstants.KEY_LEFT_TRIGGER:
                keyEventMsg = "KEY_LEFT_TRIGGER:" + suffix;
                break;
            case KeyConstants.KEY_RIGHT_TRIGGER:
                keyEventMsg = "KEY_RIGHT_TRIGGER:" + suffix;
                break;
            case KeyConstants.KEY_LEFT_SIDE_TRIGGER:
                keyEventMsg = "KEY_LEFT_SIDE_TRIGGER:" + suffix;
                break;
            case KeyConstants.KEY_RIGHT_SIDE_TRIGGER:
                keyEventMsg = "KEY_RIGHT_SIDE_TRIGGER:" + suffix;
                break;
            case KeyConstants.KEY_LEFT_THUMBSTICK:
                keyEventMsg = "KEY_LEFT_THUMBSTICK:" + suffix;
                break;
            case KeyConstants.KEY_RIGHT_THUMBSTICK:
                keyEventMsg = "KEY_RIGHT_THUMBSTICK:" + suffix;
                break;
        }
        if (baseActivity != null) {
            Message message = Message.obtain();
            message.what = baseActivity.MSG_UPDATE_TEXTVIEW;
            message.obj = keyEventMsg;
            baseActivity.mHandle.sendMessage(message);
        }
    }

    @Override
    protected String itemClickResult() {
        ToBServiceHelper.getInstance().setTrackingKeyEventCallback(new IKeyEventCallback() {
            @Override
            public void onKeyDown(int mask) {
                printKeyEventInfo(mask, true);
            }

            @Override
            public void onKeyUp(int mask) {
                printKeyEventInfo(mask, false);
            }
        });
        return null;
    }
}
