package com.yvr.testtobsetting.test;

import android.annotation.SuppressLint;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.ImageFormat;
import android.graphics.Paint;
import android.graphics.PixelFormat;
import android.graphics.Rect;
import android.graphics.YuvImage;
import android.media.Image;
import android.media.ImageReader;
import android.os.Environment;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.util.AttributeSet;
import android.util.Log;
import android.view.Surface;
import android.view.View;
import android.widget.ImageView;

import androidx.annotation.Nullable;

import com.yvr.tobsettings.ToBServiceHelper;

import java.io.BufferedOutputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.Buffer;
import java.nio.ByteBuffer;

public class TestScreenRecordView extends ImageView {
    private int width = 1920;
    private int height = 1080;
    ImageReader imageReader;
    Surface surface;
    int index = 0;
    private HandlerThread handlerThread = null;
    private Handler mHandler = null;
    private Handler mainHandler = null;
    private MyRunnable myRunnable = null;
    ImageReader.OnImageAvailableListener imageAvailableListener = new ImageReader.OnImageAvailableListener() {
        @Override
        public void onImageAvailable(ImageReader reader) {
            updateCustomView();
        }
    };

    public TestScreenRecordView(Context context) {
        this(context, null);
    }

    public TestScreenRecordView(Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public TestScreenRecordView(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        this(context, attrs, defStyleAttr, 0);
    }

    public TestScreenRecordView(Context context, @Nullable AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
    }


    @SuppressLint("WrongConstant")
    public void initImageReader() {
        if (imageReader == null) {
            mainHandler = new Handler(Looper.getMainLooper());
            handlerThread = new HandlerThread("imagereader_screenrecode");
            handlerThread.start();
            mHandler = new Handler(handlerThread.getLooper());
            imageReader = ImageReader.newInstance(width, height, PixelFormat.RGBA_8888, 10);
            surface = imageReader.getSurface();
            imageReader.setOnImageAvailableListener(imageAvailableListener, mHandler);
        }
    }

    private void updateCustomView() {
        Image image = imageReader.acquireNextImage();
        if (image != null) {
            imageToBitmap(image);
            image.close();
        }
    }

    private void imageToBitmap(Image image) {
        Image.Plane[] planes = image.getPlanes();
        ByteBuffer buffer = planes[0].getBuffer();

        int pixelStride = planes[0].getPixelStride();
        int rowStride = planes[0].getRowStride();
        int rowPadding = rowStride - pixelStride * width;
        saveRgb2Bitmap(getContext(), buffer, index++ + "_screen.png", width + rowPadding / pixelStride, height);
    }

    public void saveRgb2Bitmap(Context context, Buffer buf, String filename, int width, int height) {
        Bitmap bmp = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888);
        bmp.copyPixelsFromBuffer(buf);
        if (myRunnable == null) {
            myRunnable = new MyRunnable();
        }
        myRunnable.setBitmap(bmp);
        mainHandler.post(myRunnable);

        //save image
       /* if (bmp != null) {
            File externalFilesDir = context.getCacheDir();
            File imageFilename = new File(externalFilesDir, filename);
            BufferedOutputStream bos = null;
            try {
                bos = new BufferedOutputStream(new FileOutputStream(imageFilename));
                bmp.compress(Bitmap.CompressFormat.JPEG, 100, bos);
                bos.flush();
            } catch (IOException e) {
                e.printStackTrace();
            } finally {
                if (bos != null) {
                    try {
                        bos.close();
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
            }
        }*/
        postInvalidateOnAnimation();
    }


    public void startRecord() {
        if (surface != null) {
            ToBServiceHelper.getInstance().startRecordScreenBySurface(surface, width, height, 0);
        }
    }

    public void stopRecord() {
        if (surface != null) {
            ToBServiceHelper.getInstance().stopRecordScreenBySurface();
        }
    }

    class MyRunnable implements Runnable {
        Bitmap mBitmap;

        public void setBitmap(Bitmap mBitmap) {
            this.mBitmap = mBitmap;
        }

        @Override
        public void run() {
            setImageBitmap(mBitmap);
        }
    }
}
