package com.yvr.testtobsetting.test;

import android.content.Context;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import android.widget.Toast;

import androidx.annotation.RequiresApi;

import com.yvr.testtobsetting.R;
import com.yvr.testtobsetting.base.BaseFiveItems;
import com.yvr.testtobsetting.base.BaseFourItems;
import com.yvr.testtobsetting.base.BaseItem;
import com.yvr.tobsettings.ToBServiceHelper;
import com.yvr.tobsettings.interfaces.ConnectionSuccessListener;
import com.yvr.tobsettings.interfaces.IBoolCallback;

import java.util.function.Consumer;

public class WifiTest extends BaseFiveItems {
    final Context mContext;

    public WifiTest(Context context) {
        super(context);
        mContext = context;
    }

    @Override
    public String getFiveName() {
        return "getWifiMac";
    }

    @Override
    public String fiveItemClickResult() {
        final String wifiMac = ToBServiceHelper.getInstance().getWifiMac();
        return "getWifiMac: " + wifiMac;
    }

    @Override
    public String getName() {
        return mContext.getString(R.string.connect_wifi) + "[YVR:iloveyvr]";
    }

    @RequiresApi(api = Build.VERSION_CODES.N)
    @Override
    protected String itemClickResult() {
        final boolean result = ToBServiceHelper.getInstance().connectWifiAp("YVR", "iloveyvr", new Consumer<String>() {
            @Override
            public void accept(String s) {
                Log.d(TAG, "connectWifiAp accept " + s);
                new Handler(Looper.getMainLooper()).post(() -> {
                    Toast.makeText(mContext, "connectWifiAp " + s, Toast.LENGTH_LONG).show();
                });
            }
        });
        return "connectWifiAp: " + result;
    }

    @Override
    public String getSecondName() {
        return mContext.getString(R.string.wifi_state);
    }

    @RequiresApi(api = Build.VERSION_CODES.N)
    @Override
    public String secondItemClickResult() {
        boolean b = ToBServiceHelper.getInstance().isWifiOn(new Consumer<Boolean>() {
            @Override
            public void accept(Boolean aBoolean) {
                Log.i(TAG, "callback is wifi on:" + aBoolean);
            }
        });

        return showResult(R.string.wifi_state, b ? "ON" : "OFF");
    }

    @Override
    public String getThirdName() {
        return mContext.getString(R.string.wifi_connected_device_name);
    }

    @RequiresApi(api = Build.VERSION_CODES.N)
    @Override
    public String thirdItemClickResult() {
        String name = ToBServiceHelper.getInstance().getWifiNameConnected(new Consumer<String>() {
            @Override
            public void accept(String s) {
                Log.i(TAG, "callback device name:" + s);
            }
        });

        return showResult(R.string.wifi_connected_device_name, name);
    }

    @Override
    public String getFourthName() {
        return mContext.getString(R.string.wifi_address);
    }

    @RequiresApi(api = Build.VERSION_CODES.N)
    @Override
    public String fourthItemClickResult() {
        String address = ToBServiceHelper.getInstance().getWifiIP(new Consumer<String>() {
            @Override
            public void accept(String s) {
                Log.i(TAG, "callback device address:" + s);
            }
        });

        return showResult(R.string.wifi_address, address);
    }
}
